@@ -1,4 +1,3 @@
-/* $Xorg: imRm.c,v 1.4 2000/08/17 19:45:14 cpqbld Exp $ */
 /******************************************************************
 
 	  Copyright 1990, 1991, 1992,1993, 1994 by FUJITSU LIMITED
@@ -30,7 +29,6 @@ PERFORMANCE OF THIS SOFTWARE.
 			       makoto@sm.sony.co.jp
 
 ******************************************************************/
-/* $XFree86: xc/lib/X11/imRm.c,v 3.12 2003/04/13 19:22:21 dawes Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -410,7 +408,7 @@ _XimDefaultIMValues(
 			 = (char **)((char *)tmp + sizeof(XIMValuesList));
 	for(i = 0; i < n; i++) {
 	    values_list->supported_values[i] =
-                name_table + supported_local_im_values_list[i];
+		(char *)name_table + supported_local_im_values_list[i];
 	}
     }
 
@@ -447,7 +445,7 @@ _XimDefaultICValues(
 			 = (char **)((char *)tmp + sizeof(XIMValuesList));
 	for(i = 0; i < n; i++) {
 	    values_list->supported_values[i] =
-                name_table + supported_local_ic_values_list[i];
+		(char *)name_table + supported_local_ic_values_list[i];
 	}
     }
 
@@ -596,7 +594,7 @@ _XimDefaultArea(
     if(XGetGeometry(im->core.display, (Drawable)ic->core.focus_window,
 		&root_return, &x_return, &y_return, &width_return,
 		&height_return, &border_width_return, &depth_return)
-		== (Status)NULL) {
+		== (Status)Success) {
 	return True;
     }
     area.x	= 0;
@@ -625,7 +623,7 @@ _XimDefaultColormap(
 	return True;
     }
     if(XGetWindowAttributes(im->core.display, ic->core.client_window,
-					&win_attr) == (Status)NULL) {
+					&win_attr) == (Status)Success) {
 	return True;
     }
 
@@ -2380,10 +2378,7 @@ Public int
 }
 
 Public void
-_XimSetICMode(res_list, list_num, style)
-    XIMResourceList	res_list;
-    unsigned int	list_num;
-    XIMStyle		style;
+_XimSetICMode(XIMResourceList res_list, unsigned int list_num, XIMStyle style)
 {
     XIMResourceList	res;
     unsigned int	n = XIMNumber(ic_mode);
@@ -3018,13 +3013,8 @@ _XimDecodeLocalICAttr(
 }
 
 Public char *
-_XimGetICValueData(ic, top, res_list, list_num, values, mode)
-    Xic			 ic;
-    XPointer		 top;
-    XIMResourceList	 res_list;
-    unsigned int	 list_num;
-    XIMArg		*values;
-    unsigned long	 mode;
+_XimGetICValueData(Xic ic, XPointer top, XIMResourceList res_list,
+		   unsigned int	 list_num, XIMArg *values, unsigned long mode)
 {
     register  XIMArg	*p;
     XIMResourceList	 res;
@@ -3072,9 +3062,7 @@ _XimGetICValueData(ic, top, res_list, list_num, values, mode)
 }
 
 Public void
-_XimGetCurrentIMValues(im, im_values)
-    Xim			 im;
-    XimDefIMValues	*im_values;
+_XimGetCurrentIMValues(Xim im, XimDefIMValues *im_values)
 {
     bzero((char *)im_values, sizeof(XimDefIMValues));
 
@@ -3088,9 +3076,7 @@ _XimGetCurrentIMValues(im, im_values)
 }
 
 Public void
-_XimSetCurrentIMValues(im, im_values)
-    Xim			 im;
-    XimDefIMValues	*im_values;
+_XimSetCurrentIMValues(Xim im, XimDefIMValues *im_values)
 {
     im->core.styles		= im_values->styles;
     im->core.im_values_list	= im_values->im_values_list;
@@ -3102,9 +3088,7 @@ _XimSetCurrentIMValues(im, im_values)
 }
 
 Public void
-_XimGetCurrentICValues(ic, ic_values)
-    Xic			 ic;
-    XimDefICValues	*ic_values;
+_XimGetCurrentICValues(Xic ic, XimDefICValues *ic_values)
 {
     bzero((char *)ic_values, sizeof(XimDefICValues));
 
